# Forecasting Intermittent Time Series 

This package contains tools for forecasting intermittent time series. The outputs will be similar to those obtained from using the R package, [tsintermittent](https://cran.r-project.org/web/packages/tsintermittent/index.html). 

## Installation

The intermittent-forecast package is hosted on PyPI and can be installed using pip.

    pip install intermittent-forecast

Alternatively, you can clone the repo

	git clone git@github.com:pmrgn/intermittent-forecast.git

## Documentation

View the [documentation](https://intermittent-forecast.readthedocs.io/en/latest/).

